can_consume

Function can_consume 

pub fn can_consume(
    consumable_parameters: &MediaStream,
    consumer_capabilities: &MediaCapabilities,
) -> bool
Check whether a consumer capability set can negotiate at least one media codec.

This is the boolean gateway used by router-core when it only needs the final compatibility result and does not need the fully negotiated RTP output.